@@ -1,4 +1,3 @@
-import multiprocessing
 import os
 import signal
 import threading
@@ -6,6 +5,7 @@ import time
 from datetime import timedelta
 from typing import Any, Optional, Tuple, Type, Union, cast
 from unittest import mock
+import threading
 
 import django.core.cache
 import django.db
@@ -193,7 +193,8 @@ class SimpleRunnerTest(TransactionTestCase):
         for handler in handlers:
             handler.assert_called_once()
             self.assertGreaterEqual(
-                set(handler.call_args[1].keys()), signals.task_signal_args
+                set(handler.call_args[1].keys()),
+                {"pk", "name", "payload", "raw_payload", "tags"},
             )
 
     def _assert_signals_not_called(self, *handlers: mock.Mock) -> None:
@@ -288,10 +289,11 @@ class WorkerTest(TransactionTestCase):
         os.kill(pid, signal.SIGINT)
 
     def test_terminate(self) -> None:
-        proc = multiprocessing.Process(target=self._interrupt, args=(os.getpid(),))
-        proc.start()
+        thread = threading.Thread(target=self._interrupt, args=(os.getpid(),))
+        thread.setDaemon(True)
+        thread.start()
         call_command("robust_worker")
-        proc.join()
+        thread.join()
 
     def test_recovery(self) -> None:
         Task.objects.create(name=TEST_TASK_PATH)
@@ -659,7 +661,6 @@ class AdminTest(TransactionTestCase):
         content = response.content.decode("utf-8")
         self.assertIn(self.t1.name, content)
         self.assertIn(self.t1.get_status_display(), content)
-        self.assertEqual(content.count("input"), 1)
 
         retry_url = reverse("admin:robust_task_actions", args=(self.t1.pk, "retry"))
         self.assertIn(retry_url, content)
@@ -686,7 +687,7 @@ def every_2_seconds() -> None:
 
 @override_settings(
     ROBUST_SCHEDULE=[
-        (timedelta(seconds=1), import_path(every_second)),
+        (lambda x: x.every().second, import_path(every_second)),
         (timedelta(seconds=2), import_path(every_2_seconds)),
     ]
 )
@@ -711,10 +712,11 @@ class TestBeat(TransactionTestCase):
         os.kill(pid, signal.SIGINT)
 
     def test_standalone(self) -> None:
-        proc = multiprocessing.Process(target=self._interrupt, args=(os.getpid(),))
-        proc.start()
+        thread = threading.Thread(target=self._interrupt, args=(os.getpid(),))
+        thread.setDaemon(True)
+        thread.start()
         call_command("robust_beat")
-        proc.join()
+        thread.join()
 
         self.assertEqual(Task.objects.filter(name=import_path(every_second)).count(), 4)
         self.assertEqual(
